@@ -1,14 +1,16 @@
+# @(#)$Id: Utils.pm 78 2009-05-20 16:11:17Z pjf $
+
 package Data::Validation::Utils;
 
-# @(#)$Id: Utils.pm 70 2009-03-06 20:02:20Z pjf $
-
 use strict;
+use namespace::autoclean;
+use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 78 $ =~ /\d+/gmx );
+
 use Class::MOP;
 use English qw(-no_match_vars);
 use Moose::Role;
 use Moose::Util::TypeConstraints;
-
-use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 70 $ =~ /\d+/gmx );
+use Scalar::Util qw(blessed);
 
 subtype 'Exception' => as 'ClassName' => where { $_->can( q(throw) ) };
 
@@ -22,7 +24,7 @@ sub _load_class {
    $class =~ s{ \A $prefix }{}mx;
 
    if ($class =~ m{ \A \+ }mx) { $class =~ s{ \A \+ }{}mx }
-   else { $class = $self->blessed.q(::).(ucfirst $class) }
+   else { $class = blessed( $self ).q(::).(ucfirst $class) }
 
    eval { Class::MOP::load_class( $class ) };
 
@@ -31,12 +33,6 @@ sub _load_class {
    return bless $self, $class;
 }
 
-sub _will {
-   my ($self, $method) = @_;
-
-   return $method ? defined &{ $self->blessed.q(::).$method } : 0;
-}
-
 no Moose::Role; no Moose::Util::TypeConstraints;
 
 1;
@@ -51,7 +47,7 @@ Data::Validation::Utils - Code and attribute reuse
 
 =head1 Version
 
-0.2.$Revision: 70 $
+0.2.$Revision: 78 $
 
 =head1 Synopsis
 
@@ -92,10 +88,6 @@ then call L</isMathchingRegex> to perform the actual validation
 
 Load the external plugin subclass at run time
 
-=head2 _will
-
-Tests to see if the given method is a defined subroutine
-
 =head1 Diagnostics
 
 None
